#ifndef NT2_INCLUDE_FUNCTIONS_POSMAX_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_POSMAX_HPP_INCLUDED

#include <nt2/reduction/include/functions/posmax.hpp>

#endif
